jamtorch.distributions package
==============================

Submodules
----------

jamtorch.distributions.base module
----------------------------------

.. automodule:: jamtorch.distributions.base
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.distributions.discrete module
--------------------------------------

.. automodule:: jamtorch.distributions.discrete
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.distributions.fns module
---------------------------------

.. automodule:: jamtorch.distributions.fns
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.distributions.normal module
------------------------------------

.. automodule:: jamtorch.distributions.normal
   :members:
   :undoc-members:
   :show-inheritance:

jamtorch.distributions.uniform module
-------------------------------------

.. automodule:: jamtorch.distributions.uniform
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jamtorch.distributions
   :members:
   :undoc-members:
   :show-inheritance:
